@@ -129,7 +129,7 @@ class Exceptions:
 
 class MemoryDBClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html)
     """
 
@@ -147,7 +147,7 @@ class MemoryDBClient(BaseClient):
         """
         Apply the service update to a list of clusters supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.batch_update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#batch_update_cluster)
         """
 
@@ -155,7 +155,7 @@ class MemoryDBClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#can_paginate)
         """
 
@@ -171,7 +171,7 @@ class MemoryDBClient(BaseClient):
         """
         Makes a copy of an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.copy_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#copy_snapshot)
         """
 
@@ -181,7 +181,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_acl)
         """
 
@@ -213,7 +213,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_cluster)
         """
 
@@ -228,7 +228,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a new MemoryDB parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_parameter_group)
         """
 
@@ -243,7 +243,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a copy of an entire cluster at a specific moment in time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_snapshot)
         """
 
@@ -258,7 +258,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_subnet_group)
         """
 
@@ -273,7 +273,7 @@ class MemoryDBClient(BaseClient):
         """
         Creates a MemoryDB user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#create_user)
         """
 
@@ -281,7 +281,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_acl)
         """
 
@@ -291,7 +291,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_cluster)
         """
 
@@ -301,7 +301,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes the specified parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_parameter_group)
         """
 
@@ -309,7 +309,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes an existing snapshot.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_snapshot)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_snapshot)
         """
 
@@ -317,7 +317,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_subnet_group)
         """
 
@@ -325,7 +325,7 @@ class MemoryDBClient(BaseClient):
         """
         Deletes a user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#delete_user)
         """
 
@@ -333,12 +333,10 @@ class MemoryDBClient(BaseClient):
         self, *, ACLName: str = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeACLsResponseTypeDef:
         """
-        Returns a list of ACLs See also: `AWS API Documentation
-        <https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/DescribeACLs>`_
-        **Request Syntax** response = client.describe_acls( ACLName='string',
-        MaxResults=123, NextToken='string' ).
+        Returns a list of ACLs See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/DescribeACLs).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_acls)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_acls)
         """
 
@@ -354,7 +352,7 @@ class MemoryDBClient(BaseClient):
         Returns information about all provisioned clusters if no cluster identifier is
         specified, or about a specific cluster if a cluster name is supplied.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_clusters)
         """
 
@@ -370,7 +368,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of the available Redis engine versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_engine_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_engine_versions)
         """
 
@@ -388,7 +386,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns events related to clusters, security groups, and parameter groups.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_events)
         """
 
@@ -398,7 +396,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of parameter group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_parameter_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameter_groups)
         """
 
@@ -408,7 +406,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns the detailed parameter list for a particular parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_parameters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_parameters)
         """
 
@@ -422,12 +420,10 @@ class MemoryDBClient(BaseClient):
         NextToken: str = ...
     ) -> DescribeServiceUpdatesResponseTypeDef:
         """
-        Returns details of the service updates See also: `AWS API Documentation <https:/
-        /docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/DescribeServiceUpdates>`_
-        **Request Syntax** response = client.describe_service_updates(
-        ServiceUpdateName='string', ClusterNames=[ ...
+        Returns details of the service updates See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/DescribeServiceUpdates).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_service_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_service_updates)
         """
 
@@ -444,7 +440,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns information about cluster snapshots.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_snapshots)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_snapshots)
         """
 
@@ -454,7 +450,7 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of subnet group descriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_subnet_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_subnet_groups)
         """
 
@@ -469,18 +465,16 @@ class MemoryDBClient(BaseClient):
         """
         Returns a list of users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#describe_users)
         """
 
     def failover_shard(self, *, ClusterName: str, ShardName: str) -> FailoverShardResponseTypeDef:
         """
-        Used to failover a shard See also: `AWS API Documentation
-        <https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/FailoverShard>`_
-        **Request Syntax** response = client.failover_shard( ClusterName='string',
-        ShardName='string' ).
+        Used to failover a shard See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/FailoverShard).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.failover_shard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#failover_shard)
         """
 
@@ -494,7 +488,7 @@ class MemoryDBClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#generate_presigned_url)
         """
 
@@ -505,7 +499,7 @@ class MemoryDBClient(BaseClient):
         Lists all available node types that you can scale to from your cluster's current
         node type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.list_allowed_node_type_updates)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_allowed_node_type_updates)
         """
 
@@ -513,7 +507,7 @@ class MemoryDBClient(BaseClient):
         """
         Lists all tags currently on a named resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#list_tags)
         """
 
@@ -528,7 +522,7 @@ class MemoryDBClient(BaseClient):
         Modifies the parameters of a parameter group to the engine or system default
         value.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.reset_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#reset_parameter_group)
         """
 
@@ -538,7 +532,7 @@ class MemoryDBClient(BaseClient):
         """
         A tag is a key-value pair where the key and value are case-sensitive.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#tag_resource)
         """
 
@@ -546,12 +540,10 @@ class MemoryDBClient(BaseClient):
         self, *, ResourceArn: str, TagKeys: Sequence[str]
     ) -> UntagResourceResponseTypeDef:
         """
-        Use this operation to remove tags on a resource See also: `AWS API Documentation
-        <https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/UntagResource>`_
-        **Request Syntax** response = client.untag_resource( ResourceArn='string',
-        TagKeys=[ 'string', ] ...
+        Use this operation to remove tags on a resource See also: [AWS API
+        Documentation](https://docs.aws.amazon.com/goto/WebAPI/memorydb-2021-01-01/UntagResource).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#untag_resource)
         """
 
@@ -565,7 +557,7 @@ class MemoryDBClient(BaseClient):
         """
         Changes the list of users that belong to the Access Control List.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.update_acl)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.update_acl)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_acl)
         """
 
@@ -590,7 +582,7 @@ class MemoryDBClient(BaseClient):
         """
         Modifies the settings for a cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.update_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_cluster)
         """
 
@@ -600,7 +592,7 @@ class MemoryDBClient(BaseClient):
         """
         Updates the parameters of a parameter group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.update_parameter_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_parameter_group)
         """
 
@@ -610,7 +602,7 @@ class MemoryDBClient(BaseClient):
         """
         Updates a subnet group.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.update_subnet_group)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_subnet_group)
         """
 
@@ -624,6 +616,6 @@ class MemoryDBClient(BaseClient):
         """
         Changes user password(s) and/or access string.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/memorydb.html#MemoryDB.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.46/reference/services/memorydb.html#MemoryDB.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client.html#update_user)
         """
